package com.fs.qw.service;


import com.fs.qw.domain.QwGroupMsgItem;

import java.util.List;

/**
 * 客户群发消息的附件记录Service接口
 *
 * @author fs
 * @date 2024-06-28
 */
public interface IQwGroupMsgItemService
{
    /**
     * 查询客户群发消息的附件记录
     *
     * @param id 客户群发消息的附件记录主键
     * @return 客户群发消息的附件记录
     */
    public QwGroupMsgItem selectQwGroupMsgItemById(Long id);

    /**
     * 查询客户群发消息的附件记录列表
     *
     * @param qwGroupMsgItem 客户群发消息的附件记录
     * @return 客户群发消息的附件记录集合
     */
    public List<QwGroupMsgItem> selectQwGroupMsgItemList(QwGroupMsgItem qwGroupMsgItem);

    /**
     * 新增客户群发消息的附件记录
     *
     * @param qwGroupMsgItem 客户群发消息的附件记录
     * @return 结果
     */
    public int insertQwGroupMsgItem(QwGroupMsgItem qwGroupMsgItem);

    /**
     * 修改客户群发消息的附件记录
     *
     * @param qwGroupMsgItem 客户群发消息的附件记录
     * @return 结果
     */
    public int updateQwGroupMsgItem(QwGroupMsgItem qwGroupMsgItem);

    /**
     * 批量删除客户群发消息的附件记录
     *
     * @param ids 需要删除的客户群发消息的附件记录主键集合
     * @return 结果
     */
    public int deleteQwGroupMsgItemByIds(Long[] ids);

    /**
     * 删除客户群发消息的附件记录信息
     *
     * @param id 客户群发消息的附件记录主键
     * @return 结果
     */
    public int deleteQwGroupMsgItemById(Long id);
}
